@@ -1,21 +1,22 @@
-/*
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
  * test-completion.c
+ * This file is part of GtkSourceView
  *
- * Copyright (C) 2007 Jesús Barbero Rodríguez <chuchiperriman@gmail.com>
+ * Copyright (C) 2007 - Jesús Barbero Rodríguez <chuchiperriman@gmail.com>
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Library General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * GtkSourceView is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * GtkSourceView is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include <config.h>
@@ -129,10 +130,10 @@ test_provider_init (TestProvider *self)
 	GdkPixbuf *icon = test_provider_get_icon (GTK_SOURCE_COMPLETION_PROVIDER (self));
 
 	proposals = g_list_prepend (proposals,
-	                            gtk_source_completion_item_new ("Proposal 3", "Proposal 3", icon, NULL));
+	                            gtk_source_completion_item_new ("Proposal 3", "Proposal 3", icon, "This is the third proposal... \nit is so cool it takes two lines to describe"));
 
 	proposals = g_list_prepend (proposals,
-	                            gtk_source_completion_item_new ("Proposal 2", "Proposal 2", icon, NULL));
+	                            gtk_source_completion_item_new ("Proposal 2", "Proposal 2", icon, "This is the second proposal... it is very appealing..."));
 
 	proposals = g_list_prepend (proposals,
 	                            gtk_source_completion_item_new ("Proposal 1", "Proposal 1", icon, NULL));
@@ -141,7 +142,7 @@ test_provider_init (TestProvider *self)
 }
 
 static void
-destroy_cb (GtkObject *object,
+destroy_cb (GtkWidget *object,
 	    gpointer   user_data)
 {
 	gtk_main_quit ();
@@ -295,14 +296,13 @@ create_completion(void)
 int
 main (int argc, char *argv[])
 {
- 	GtkWidget *window;
-	
-	gtk_set_locale ();
+	GtkWidget *window;
+
 	gtk_init (&argc, &argv);
 
 	window = create_window ();
 	create_completion ();
-	
+
 	gtk_widget_show_all (window);
 
 	gtk_main ();
